@@ -23,7 +23,7 @@ class YDTK:
         url = "https://note.youdao.com/yws/public/note/" + self.get_shared_id()
         r = requests.get(url)
         j = r.json()
-        return get_re_last('<img data-media-type="image" src="(.*?)".*?>', j["content"])
+        return "http://" + get_re_last('<img data-media-type="image" src="(.*?)".*?>', j["content"])[7:]
 
 
 def ydtk(yd_tk_doc_url):
@@ -36,4 +36,4 @@ def main():
     globals()[func_name](*args)
 
 if __name__ == '__main__':
-    main()
\ No newline at end of file
+    main()
